@@ -15,7 +15,7 @@
 #'   the release are \sQuote{devel},
 #'   \sQuote{release} (the default if none specified), or numeric release
 #'   numbers (e.g. \sQuote{3.3}).
-#' @param mirror The bioconductor git mirror to use
+#' @param mirror The Bioconductor git mirror to use
 #' @param ... Other arguments passed on to [utils::install.packages()].
 #' @inheritParams install_github
 #' @export
@@ -23,7 +23,7 @@
 #' @examples
 #' \dontrun{
 #' install_bioc("SummarizedExperiment")
-#' install_bioc("release/SummarizedExperiment")
+#' install_bioc("devel/SummarizedExperiment")
 #' install_bioc("3.3/SummarizedExperiment")
 #' install_bioc("SummarizedExperiment#abc123")
 #' install_bioc("user:password@release/SummarizedExperiment")
@@ -254,17 +254,20 @@ bioconductor_branch <- function(release, sha) {
     sha
   } else {
     if (is.null(release)) {
-      release <- "release"
+      release <- Sys.getenv("R_BIOC_VERSION", "release")
     }
     if (release == "release") {
       release <- bioconductor_release()
+    } else if (release == bioconductor$get_devel_version()) {
+      release <- "devel"
     }
     switch(
       tolower(release),
-      devel = "master",
+      devel = "HEAD",
       paste0("RELEASE_",  gsub("\\.", "_", release))
     )
   }
+
 }
 
 bioconductor_release <- function() {
@@ -298,4 +301,3 @@ git_repo_sha1 <- function(r) {
     git2r::branch_target(rev)
   }
 }
-
