@@ -5,6 +5,10 @@
 #' a single command. You do not need to have the `git2r` package,
 #' or an external git client installed.
 #'
+#' If you need to set git credentials for use in the `Remotes` field you can do
+#' so by placing the credentials in the `remotes.git_credentials` global
+#' option.
+#'
 #' @param url Location of package. The url should point to a public or
 #'   private repository.
 #' @param ref Name of branch, tag or SHA reference to use, if not HEAD.
@@ -22,45 +26,50 @@
 #' @export
 #' @examples
 #' \dontrun{
-#' install_git("git://github.com/hadley/stringr.git")
-#' install_git("git://github.com/hadley/stringr.git", ref = "stringr-0.2")
-#'}
+#' install_git("https://github.com/hadley/stringr.git")
+#' install_git("https://github.com/hadley/stringr.git", ref = "stringr-0.2")
+#' }
 install_git <- function(url, subdir = NULL, ref = NULL, branch = NULL,
-                        credentials = NULL,
+                        credentials = git_credentials(),
                         git = c("auto", "git2r", "external"),
                         dependencies = NA,
                         upgrade = c("default", "ask", "always", "never"),
                         force = FALSE,
                         quiet = FALSE,
                         build = TRUE, build_opts = c("--no-resave-data", "--no-manual", "--no-build-vignettes"),
+                        build_manual = FALSE, build_vignettes = FALSE,
                         repos = getOption("repos"),
                         type = getOption("pkgType"),
                         ...) {
-
   if (!missing(branch)) {
     warning("`branch` is deprecated, please use `ref`")
     ref <- branch
   }
 
-  remotes <- lapply(url, git_remote, subdir = subdir, ref = ref,
-    credentials = credentials, git = match.arg(git))
+  remotes <- lapply(url, git_remote,
+    subdir = subdir, ref = ref,
+    credentials = credentials, git = match.arg(git)
+  )
 
-  install_remotes(remotes, credentials = credentials,
-                  dependencies = dependencies,
-                  upgrade = upgrade,
-                  force = force,
-                  quiet = quiet,
-                  build = build,
-                  build_opts = build_opts,
-                  repos = repos,
-                  type = type,
-                  ...)
+  install_remotes(remotes,
+    credentials = credentials,
+    dependencies = dependencies,
+    upgrade = upgrade,
+    force = force,
+    quiet = quiet,
+    build = build,
+    build_opts = build_opts,
+    build_manual = build_manual,
+    build_vignettes = build_vignettes,
+    repos = repos,
+    type = type,
+    ...
+  )
 }
 
 
-git_remote <- function(url, subdir = NULL, ref = NULL, credentials = NULL,
+git_remote <- function(url, subdir = NULL, ref = NULL, credentials = git_credentials(),
                        git = c("auto", "git2r", "external"), ...) {
-
   git <- match.arg(git)
   if (git == "auto") {
     git <- if (!is_standalone() && pkg_installed("git2r")) "git2r" else "external"
@@ -70,11 +79,14 @@ git_remote <- function(url, subdir = NULL, ref = NULL, credentials = NULL,
     stop("`credentials` can only be used with `git = \"git2r\"`", call. = FALSE)
   }
 
-  list(git2r = git_remote_git2r, external = git_remote_xgit)[[git]](url, subdir, ref, credentials)
+  meta <- re_match(url, "(?:(?<url>[^@]*))(?:@(?<ref>.*))?")
+  ref <- ref %||% (if (meta$ref == "") NULL else meta$ref)
+
+  list(git2r = git_remote_git2r, external = git_remote_xgit)[[git]](meta$url, subdir, ref, credentials)
 }
 
 
-git_remote_git2r <- function(url, subdir = NULL, ref = NULL, credentials = NULL) {
+git_remote_git2r <- function(url, subdir = NULL, ref = NULL, credentials = git_credentials()) {
   remote("git2r",
     url = url,
     subdir = subdir,
@@ -84,7 +96,7 @@ git_remote_git2r <- function(url, subdir = NULL, ref = NULL, credentials = NULL)
 }
 
 
-git_remote_xgit <- function(url, subdir = NULL, ref = NULL, credentials = NULL) {
+git_remote_xgit <- function(url, subdir = NULL, ref = NULL, credentials = git_credentials()) {
   remote("xgit",
     url = url,
     subdir = subdir,
@@ -129,48 +141,65 @@ remote_metadata.git2r_remote <- function(x, bundle = NULL, source = NULL, sha =
 
 #' @export
 remote_package_name.git2r_remote <- function(remote, ...) {
-
   tmp <- tempfile()
   on.exit(unlink(tmp))
   description_path <- paste0(collapse = "/", c(remote$subdir, "DESCRIPTION"))
 
-  # Try using git archive --remote to retrieve the DESCRIPTION, if the protocol
-  # or server doesn't support that return NA
-  res <- try(silent = TRUE,
-    system_check(git_path(),
-      args = c("archive", "-o", tmp, "--remote", remote$url,
-        if (is.null(remote$ref)) "HEAD" else remote$ref,
-        description_path),
-      quiet = TRUE))
+  if (grepl("^https?://", remote$url)) {
+    url <- build_url(sub("\\.git$", "", remote$url), "raw", remote_sha(remote, ...), description_path)
+    download(tmp, url)
+    read_dcf(tmp)$Package
+  } else {
+    # Try using git archive --remote to retrieve the DESCRIPTION, if the protocol
+    # or server doesn't support that return NA
+    res <- try(
+      silent = TRUE,
+      system_check(git_path(),
+        args = c(
+          "archive", "-o", tmp, "--remote", remote$url,
+          if (is.null(remote$ref)) "HEAD" else remote$ref,
+          description_path
+        ),
+        quiet = TRUE
+      )
+    )
 
-  if (inherits(res, "try-error")) {
-    return(NA_character_)
+    if (inherits(res, "try-error")) {
+      return(NA_character_)
+    }
+
+    # git archive returns a tar file, so extract it to tempdir and read the DCF
+    utils::untar(tmp, files = description_path, exdir = tempdir())
+
+    read_dcf(file.path(tempdir(), description_path))$Package
   }
-
-  # git archive returns a tar file, so extract it to tempdir and read the DCF
-  utils::untar(tmp, files = description_path, exdir = tempdir())
-
-  read_dcf(file.path(tempdir(), description_path))$Package
 }
 
 #' @export
 remote_sha.git2r_remote <- function(remote, ...) {
-  tryCatch({
-    # set suppressWarnings in git2r 0.23.0+
-    res <- suppressWarnings(git2r::remote_ls(remote$url, credentials=remote$credentials))
+  tryCatch(
+    {
+      # set suppressWarnings in git2r 0.23.0+
+      res <- suppressWarnings(git2r::remote_ls(remote$url, credentials = remote$credentials))
 
-    # This needs to be master, not HEAD because no ref is called HEAD
-    ref <- remote$ref %||% "master"
+      ref <- remote$ref %||% "HEAD"
 
-    found <- grep(pattern = paste0("/", ref), x = names(res))
+      if (ref != "HEAD") ref <- paste0("/", ref)
 
-    # If none found, it is either a SHA, so return the pinned sha or NA
-    if (length(found) == 0) {
-      return(remote$ref %||% NA_character_)
+      found <- grep(pattern = paste0(ref, "$"), x = names(res))
+
+      # If none found, it is either a SHA, so return the pinned sha or NA
+      if (length(found) == 0) {
+        return(remote$ref %||% NA_character_)
+      }
+
+      unname(res[found[1]])
+    },
+    error = function(e) {
+      warning(e)
+      NA_character_
     }
-
-    unname(res[found[1]])
-  }, error = function(e) { warning(e);  NA_character_})
+  )
 }
 
 #' @export
@@ -191,11 +220,15 @@ remote_download.xgit_remote <- function(x, quiet = FALSE) {
 
   bundle <- tempfile()
 
-  args <- c('clone', '--depth', '1', '--no-hardlinks')
-  if (!is.null(x$ref)) args <- c(args, "--branch", x$ref)
+  args <- c("clone", "--depth", "1", "--no-hardlinks")
   args <- c(args, x$args, x$url, bundle)
   git(paste0(args, collapse = " "), quiet = quiet)
 
+  if (!is.null(x$ref)) {
+    git(paste0(c("fetch", "origin", x$ref), collapse = " "), quiet = quiet, path = bundle)
+    git(paste0(c("checkout", "FETCH_HEAD"), collapse = " "), quiet = quiet, path = bundle)
+  }
+
   bundle
 }
 
@@ -227,9 +260,26 @@ remote_sha.xgit_remote <- function(remote, ...) {
 
   refs <- git(paste("ls-remote", url, ref))
 
-  refs_df <- read.delim(text = refs, stringsAsFactors = FALSE, sep = "\t",
-    header = FALSE)
+  # If none found, it is either a SHA, so return the pinned SHA or NA
+  if (length(refs) == 0) {
+    return(remote$ref %||% NA_character_)
+  }
+
+  refs_df <- read.delim(
+    text = refs, stringsAsFactors = FALSE, sep = "\t",
+    header = FALSE
+  )
   names(refs_df) <- c("sha", "ref")
 
   refs_df$sha[[1]]
 }
+
+#' Specify git credentials to use
+#'
+#' The global option `remotes.git_credentials` is used to set the git
+#' credentials.
+#' @export
+#' @keywords internal
+git_credentials <- function() {
+  getOption("remotes.git_credentials", NULL)
+}
