@@ -4,13 +4,16 @@
 #' packages in a single command.
 #'
 #' @param repo Repository address in the format
-#'   `username/repo[/subdir][@@ref|#pull]`. Alternatively, you can
+#'   `username/repo[/subdir][@@ref|#pull|@@*release]`. Alternatively, you can
 #'   specify `subdir` and/or `ref` using the respective parameters
-#'   (see below); if both is specified, the values in `repo` take
+#'   (see below); if both are specified, the values in `repo` take
 #'   precedence.
 #' @param ref Desired git reference. Could be a commit, tag, or branch
-#'   name, or a call to [github_pull()]. Defaults to `"master"`.
-#' @param subdir subdirectory within repo that contains the R package.
+#'   name, or a call to [github_pull()] or [github_release()]. Defaults to
+#'   `"HEAD"`, which means the default branch on GitHub and for git remotes.
+#'   See [setting-the-default-branch](https://help.github.com/en/github/administering-a-repository/setting-the-default-branch)
+#'   for more details.
+#' @param subdir Subdirectory within repo that contains the R package.
 #' @param auth_token To install from a private repo, generate a personal
 #'   access token (PAT) in "https://github.com/settings/tokens" and
 #'   supply to this argument. This is safer than using a password because
@@ -34,7 +37,7 @@
 #' install_github("wch/ggplot2")
 #' install_github(c("rstudio/httpuv", "rstudio/shiny"))
 #' install_github(c("hadley/httr@@v0.4", "klutometis/roxygen#142",
-#'   "mfrasca/r-logging/pkg"))
+#'   "r-lib/roxygen2@@*release", "mfrasca/r-logging/pkg"))
 #'
 #' # To install from a private repo, use auth_token with a token
 #' # from https://github.com/settings/tokens. You only need the
@@ -42,9 +45,12 @@
 #' # GITHUB_PAT.
 #' install_github("hadley/private", auth_token = "abc")
 #'
+#' # To pass option arguments to `R CMD INSTALL` use `INSTALL_opts`. e.g. to
+#' install a package with source references and tests
+#' install_github("rstudio/shiny", INSTALL_opts = c("--with-keep.source", "--install-tests"))
 #' }
 install_github <- function(repo,
-                           ref = "master",
+                           ref = "HEAD",
                            subdir = NULL,
                            auth_token = github_pat(quiet),
                            host = "api.github.com",
@@ -75,7 +81,14 @@ install_github <- function(repo,
     ...)
 }
 
-github_remote <- function(repo, ref = "master", subdir = NULL,
+#' Create a new github_remote
+#'
+#' This is an internal function to create a new github_remote, users should
+#' generally have no need for it.
+#' @inheritParams install_github
+#' @export
+#' @keywords internal
+github_remote <- function(repo, ref = "HEAD", subdir = NULL,
                        auth_token = github_pat(), sha = NULL,
                        host = "api.github.com", ...) {
 
@@ -160,7 +173,7 @@ github_resolve_ref.default <- function(x, params, ...) {
 
 #' @export
 github_resolve_ref.NULL <- function(x, params, ...) {
-  params$ref <- "master"
+  params$ref <- "HEAD"
   params
 }
 
